#ifndef E_H
#define E_H
#define HEADER "a.h"
#include HEADER
#include "b.h"
const int e = a*b;
#endif
